<footer>
    <div class="container">
        <div class="footer-content">
            <div class="footer-section">
                <h3>Connect</h3>
                <a href="https://github.com/WomB0ComB0/pg-fms">GitHub</a>
                <a href="#">Documentation</a>
                <a href="#">Community</a>
            </div>
            <div class="footer-section">
                <h3>Features</h3>
                <a href="#">File Operations</a>
                <a href="#">File Filtering</a>
                <a href="#">Cross-Platform Support</a>
            </div>
            <div class="footer-section">
                <h3>About</h3>
                <a href="#">The Team</a>
                <a href="#">Our Mission</a>
                <a href="#">Contribute</a>
            </div>
            <div class="footer-section">
                <h3>Legal</h3>
                <a href="#">Privacy Policy</a>
                <a href="#">Terms of Service</a>
            </div>
        </div>
        <div style="text-align: center; margin-top: 40px; padding-top: 20px; border-top: 1px solid #6a0080;">
            <p>&copy; 2023 PG-FMS. All rights reserved.</p>
        </div>
    </div>
</footer>
