<header>
    <div class="logo">PG-FMS</div>
    <nav>
        <a href="#features" target="_self" rel="noopener noreferrer">Features</a>
        <a href="https://womb0comb0.gitbook.io/docs.pg-fms.vercel.app" target="_blank" rel="noopener noreferrer">Documentation</a>
        <a href="https://gitlab.com/WomB0ComB0/pg-fms" class="button" target="_blank"  rel="noopener noreferrer">GitHub</a>
    </nav>
</header>
